lint_validated_roots

Function lint_validated_roots 

pub fn lint_validated_roots<'tcx>(
    tcx: TyCtxt<'tcx>,
    roots: UnordSet<MonoItem<'tcx>>,
)
Lint all used items recursively, starting from validated roots. Validated roots are calculated in rustc_monomorphize::collector::ferrocene, see there for details.

We can’t depend on anything in rustc_monomorphize here because we’re too early in rustc’s dependency graph. Instead we call this function in a query override in rustc_interface.