struct LintPostMono<'a, 'tcx> {
instance: Instance<'tcx>,
body: &'a Body<'tcx>,
linter: &'a mut LintState<'tcx>,
visited: &'a mut FxHashSet<Instance<'tcx>>,
roots: &'a [MonoItem<'tcx>],
from_instantiation: Option<InstantiationSite<'tcx>>,
}Fields
instance: Instance<'tcx>The function we are currently traversing.
body: &'a Body<'tcx>Its body.
linter: &'a mut LintState<'tcx>visited: &'a mut FxHashSet<Instance<'tcx>>A list of all functions we have previously traversed. This needs to store Instances, not DefIds, because different instantiations may call different concrete functions, and we want to make sure we lint all of them.
roots: &'a [MonoItem<'tcx>]A list of all items we are going to traverse.
This is needed to avoid non-determinism in diagnostics; we don’t want from_instantiation
to vary based on iteration order.
from_instantiation: Option<InstantiationSite<'tcx>>May be None if this is a mono root.
Implementations
Sourceimpl<'a, 'tcx> LintPostMono<'a, 'tcx>
impl<'a, 'tcx> LintPostMono<'a, 'tcx>
fn find_dynamic_cast( &self, rval: &Rvalue<'tcx>, ) -> Option<(Span, UseKind<'tcx>)>
fn use_(&self, kind: UseKind<'tcx>, span: Span) -> Use<'tcx>
fn lint(&mut self, use_: Use<'tcx>, scope: SourceScope) -> HirId
fn on_edge( &mut self, use_: Use<'tcx>, scope: SourceScope, pre_mono_callee: DefId, )
fn visit_instance( linter: &'a mut LintState<'tcx>, visited: &mut FxHashSet<Instance<'tcx>>, roots: &'a [MonoItem<'tcx>], instance: Instance<'tcx>, from_instantiation: Option<InstantiationSite<'tcx>>, )
fn get_call_def_mir( &self, terminator: &Terminator<'tcx>, _loc: Location, ) -> Option<(Instance<'tcx>, DefId)>
fn monomorphize_instance( &self, def_id: DefId, generic_args: GenericArgsRef<'tcx>, span: Span, ) -> Instance<'tcx>
fn monomorphize_args<T>(&self, generic_args: T) -> (T, TypingEnv<'tcx>)where
T: TypeFoldable<TyCtxt<'tcx>>,